@@ -13,7 +13,7 @@
 ##############################################################################
 """Resource List
 
-$Id: list.py 91567 2008-09-28 05:53:11Z srichter $
+$Id: list.py 102376 2009-07-30 16:23:25Z srichter $
 """
 __docformat__ = 'restructuredtext'
 import gzip
@@ -57,7 +57,7 @@ def getResourceUrls(resources):
         if not isinstance(res, DirectoryResource):
             # Avoid duplicate paths
             if res() not in paths:
-                paths.append(res())
+                paths.append(unicode(res()))
         # For directory resources, we want to walk the tree.
         baseURL = res()
         path = res.context.path
